@@ -5,11 +5,8 @@ package Dist::Zilla::Plugin::Run;
 BEGIN {
   $Dist::Zilla::Plugin::Run::AUTHORITY = 'cpan:GETTY';
 }
-{
-  $Dist::Zilla::Plugin::Run::VERSION = '0.019';
-}
 # ABSTRACT: Run external commands at specific phases of Dist::Zilla
-
+$Dist::Zilla::Plugin::Run::VERSION = '0.021';
 
 1;
 
@@ -23,7 +20,7 @@ Dist::Zilla::Plugin::Run - Run external commands at specific phases of Dist::Zil
 
 =head1 VERSION
 
-version 0.019
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -129,11 +126,11 @@ Individual plugins define their own values for the positional replacement of C<%
 
 =head1 AUTHOR
 
-Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by L<Raudssus Social Software|http://www.raudssus.de/>.
+This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
