@@ -5,10 +5,8 @@ package Dist::Zilla::Plugin::Run::Release;
 BEGIN {
   $Dist::Zilla::Plugin::Run::Release::AUTHORITY = 'cpan:GETTY';
 }
-{
-  $Dist::Zilla::Plugin::Run::Release::VERSION = '0.019';
-}
 # ABSTRACT: execute a command of the distribution on release
+$Dist::Zilla::Plugin::Run::Release::VERSION = '0.021';
 use Moose;
 with qw(
 	Dist::Zilla::Role::Releaser
@@ -38,7 +36,7 @@ Dist::Zilla::Plugin::Run::Release - execute a command of the distribution on rel
 
 =head1 VERSION
 
-version 0.019
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -73,11 +71,11 @@ The 1st C<%s> will be replaced by the archive of the release.
 
 =head1 AUTHOR
 
-Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by L<Raudssus Social Software|http://www.raudssus.de/>.
+This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
