@@ -5,10 +5,8 @@ package Dist::Zilla::Plugin::Run::Test;
 BEGIN {
   $Dist::Zilla::Plugin::Run::Test::AUTHORITY = 'cpan:GETTY';
 }
-{
-  $Dist::Zilla::Plugin::Run::Test::VERSION = '0.020';
-}
 # ABSTRACT: execute a command of the distribution after build
+$Dist::Zilla::Plugin::Run::Test::VERSION = '0.021';
 use Moose;
 with qw(
 	Dist::Zilla::Role::TestRunner
@@ -29,6 +27,7 @@ sub test {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -37,7 +36,7 @@ Dist::Zilla::Plugin::Run::Test - execute a command of the distribution after bui
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -63,14 +62,13 @@ There are no positional parameters for this plugin.
 
 =head1 AUTHOR
 
-Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>
+Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by L<Raudssus Social Software|http://www.raudssus.de/>.
+This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
